/*********************************************************************************************************************************
Definition of a wire structure:

1) the order of the parameters must not be changed
2) the points in the structure mat_coord(i,j) and ox_coord(i,j) must follow the order described below
3) comments must remain on one line or start again with //

Commands:

CB_Bandstructure        = conduction bandstructure of contacts
VB_Bandstructure        = valence bandstructure of contacts
CB_Transmission_UWF     = conduction band transmission with UMFPACK
VB_Transmission_UWF     = valence band transmission with UMFPACK
CB_Transmission_SWF     = conduction band transmission with SuperLU_DIST
VB_Transmission_SWF     = valence band transmission with SuperLU_DIST
CB_Transmission_MWF     = conduction band transmission with MUMPS
VB_Transmission_MWF     = valence band transmission with MUMPS
CB_Transmission_RGF     = conduction band transmission with recursive GF
VB_Transmission_RGF     = valence band transmission with recursive GF
EL_SC_UWF               = self-consistent electron simulation with UMFPACK
HO_SC_UWF               = self-consistent hole simulation with UMFPACK
EL_SC_SWF               = self-consistent electron simulation with SuperLU_DIST
HO_SC_SWF               = self-consistent hole simulation SuperLU_DIST
EL_SC_MWF               = self-consistent electron simulation with MUMPS
HO_SC_MWF               = self-consistent hole simulation MUMPS
EL_SC_RGF               = self-consistent electron simulation with recursive GF
HO_SC_RGF               = self-consistent hole simulation with recursive GF
Write_Layer_Matrix      = write file with atom positions + connections
Write_Grid_Matrix       = write file with grid points + file with index of atom position

*********************************************************************************************************************************/
/*Parameters*/

mat_name            	= ph_mat_par;
lattice_type		= lattice_dat;
a0                      = 0.1;                //lattice constant: from A to nm
read_hamiltonian	= 1;
NDim			= 2;
first_atom = anion;

poisson_solver   = 0;
poisson_iteration = 50;
poisson_inner_criterion = 5e-3;
NzFold = 1;

restart = [2 0 0 0];
sc_restart = [-3 1];
vact_file = vact_dat;


Nkz			= 1;
Temp  = 300;

n_of_modes		= 10;           //number of modes for bandstructure calculation
Nk			= 251;         //number of k points in bandstructure calculation. High Nk important for good energy grid in pMOS
bs_solver		= full;
x               = [1 0 0];			//transport direction
y               = [0 1 0];			//direction of confinement
z     			= [0 0 1];              	//direction of confinement

Eps_wire		= 4.0;                 	//Wire permitivity
Eps_ox = [16.8 3.9];
Xi_wire  = 4.05;    //semiconductor channel affinity, value in [eV].
phi_m     = 4.35;

NVG = 1;
Vgmin =  0.0;
Vgmax =  0.0;

NVS = 1;
Vsmin = 0.0;
Vsmax = 0.0;

NVD = 1;
Vdmin = 0.0;
Vdmax = 0.0;

eta_res = 1e-8;
eta     = 0.0;

Elimit = 50e-3;
Emin_tail = 50e-3;
EOffset = 25*UT;
dE_in  = 1.0e-4;  //distance between two energy points right after the presence of a state with zero-velocity in the contact bandstructure, value in [eV].
dE_f = 1.0e-3;     //distance between two energy points in regions where no singularity are present, value in [eV].
dE_sep = 1.0e-4;
NEmax = 250;
regular_mesh = 1;

update_energy = 1;
energy_file = E_dat;

sc_max_iteration = 2;
sc_scale_fact = 1;

no_ph_k         = 1;
no_ph_energy        = 1;
ph_mode_file            = EMPTY;
ph_coupling_file    = EMPTY;
sc_k_coupling       = 0;
sc_id_crit      = 1e-3;

/*********************************************************************************************************************************/
/*Structure*/

grid_accuracy  = 0;

no_mat			= 3;
no_channel_mat  = 1;
no_oxide_mat    = 2;


// number of unit cells: 212
Lc = 167.024198;
Ls = 47.024198;
Ld = 47.024198;
tc = 0.5611446;

tox = 2.2568554;
tground = 20.0;

mat_type(1) = square;
mat_id(1) = 1;
mat_cs(1) = yes;
mat_coord(1,1)	= [0. 0.];
mat_coord(1,2) = [Ls+Lc+Ld 0.];
mat_coord(1,3) = [Ls+Lc+Ld tc];
mat_coord(1,4)	= [0. tc];

ox_type(1)              = square;
ox_cs(1)                = yes;
ox_id(1)		= 1;          
ox_coord(1,1)           = [0.0 0.0];    
ox_coord(1,2)           = [Ls+Lc+Ld 0.0];
ox_coord(1,3)           = [Ls+Lc+Ld tc+tox];
ox_coord(1,4)           = [0.0 tc+tox];

ox_type(2)              = square;
ox_cs(2)                = yes;
ox_id(2)		= 2;          
ox_coord(2,1)           = [0.0 0.0-tground];    
ox_coord(2,2)           = [Ls+Lc+Ld 0.0-tground];
ox_coord(2,3)           = [Ls+Lc+Ld 0.0];
ox_coord(2,4)           = [0.0 0.0];

no_gate                 = 0;

// gate_type(1)            = square;
// gate_coord(1,1)         = [Ls tc+tox];    
// gate_coord(1,2)         = [Ls+Lc tc+tox];


no_doping  = 2;

ND_S                    = 1e25;
NA_S                    = 0e18;
ND_D                    = 1e25;
NA_D                    = 0e18;

doping_type(1)          = square;
doping_ND(1)            = ND_S;
doping_NA(1)            = NA_S;
doping_coord(1,1)       = [0.0 0.0];    
doping_coord(1,2)       = [Ls 0.0];
doping_coord(1,3)       = [Ls tc];
doping_coord(1,4)       = [0.0 tc];

doping_type(2)          = square;
doping_ND(2)            = ND_D;
doping_NA(2)            = NA_D;
doping_coord(2,1)       = [Ls+Lc 0.0];    
doping_coord(2,2)       = [Ls+Lc+Ld 0.0];
doping_coord(2,3)       = [Ls+Lc+Ld tc];
doping_coord(2,4)       = [Ls+Lc tc];

/*********************************************************************************************************************************/
/*Commands*/

command(1)		= Write_Layer_Matrix;
command(2)		= Write_Grid_Matrix;


//command(3)              = CB_Bandstructure;
//command(4)              = VB_Bandstructure;
command(3)              = Write_Fermi_Level;
//command(6)              = CB_Transmission_MWF;
//command(7)              = VB_Transmission_MWF;

command(4)             = EL_SC_SCATT;

//command(4)             = HO_SC_MWF;

//command(3)             = HO_SC_SCATT;

